FileEventContext class

The context of a Blob event request/response.

Inheritance

Constructors

FileEventContext(String id, FileEventRequest req, BlobEventResponse resp, {dynamic next = _defaultHandler<FileEventContext>})
FileEventContext.fromCtx(FileEventContext ctx, FileEventHandler next)
Call the next middleware in the middleware chain
FileEventContext.fromRequest(ServerMessage msg, Bucket bucket)
Create a Blob Event context from a server message.

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID which connects the request/response for the server handling.
finalinherited
req → FileEventRequest
The request object.
finalinherited
res → BlobEventResponse
The response object.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

next() → Future<FileEventContext>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toResponse() → ClientMessage
Converts the context to a gRPC client response.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited