MessageRequest class

Represents a request received by a subscription to a topic.

Inheritance

Constructors

MessageRequest(String topicName, Map<String, dynamic> message)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ Map<String, dynamic>
The message payload that was sent.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topicName ↔ String
The name of the topic that triggered this subscription.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited