MessageResponse class

Represents a response to a topic subscription request.

Inheritance

Constructors

MessageResponse([bool success = true])

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool
If the event request was handled successfully or not. Defaults to true.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toWire() → MessageResponse
Converts this blob event response to a gRPC response.

Operators

operator ==(Object other) → bool
The equality operator.
inherited