Nitric class

Constructors

Nitric()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

api(String name, {ApiOptions? opts}) → Api
Create a named api for registering HTTP handlers.
bucket(String name) → BucketResource
Create a named bucket for storing blobs.
job(String name) → JobResource
Create a named job for running and submitting long-running jobs
kv(String name) → KeyValueStoreResource
Create a named collection for storing documents.
oidcRule(String name, String issuer, List<String> audiences) → SecurityOption
Create a named oidc rule for attaching security definitions to APIs.
queue(String name) → QueueResource
Create a named queue for enqueuing and dequeuing messages.
schedule(String name) → Schedule
Create a named schedule for running handlers on a set interval.
secret(String name) → SecretResource
Create a named secret for storing encrypted values.
sql(String name, {String? migrations}) → SqlDatabase
Create a named sql database.
topic(String name) → Topic
Create a named topic for registering push-based event handlers.
websocket(String name) → Websocket
Create a named websocket for registering bidirectional HTTP handlers.