TriggerContext<Req extends TriggerRequest, Resp extends TriggerResponse> class

Base context to wrap request/response objects from the server.

Implementers

Constructors

TriggerContext(String id, Req req, Resp res)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID which connects the request/response for the server handling.
final
req → Req
The request object.
final
res → Resp
The response object.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited