Api class

An API resource.

Inheritance

Constructors

Api(String name, {ApiOptions? opts})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the resource.
finalinherited
opts ↔ ApiOptions
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

all(String match, HttpHandler handler, {List<OidcOptions>? security, List<HttpHandler> middlewares = const []}) → Future<void>
A request handler that matches a specific route on all HTTP methods.
asRequest() → ResourceDeclareRequest
override
delete(String match, HttpHandler handler, {List<OidcOptions>? security, List<HttpHandler> middlewares = const []}) → Future<void>
A DELETE request handler that matches a specific route.
get(String match, HttpHandler handler, {List<OidcOptions>? security, List<HttpHandler> middlewares = const []}) → Future<void>
A GET request handler that matches a specific route.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
options(String match, HttpHandler handler, {List<OidcOptions>? security, List<HttpHandler> middlewares = const []}) → Future<void>
A OPTIONS request handler that matches a specific route.
patch(String match, HttpHandler handler, {List<OidcOptions>? security, List<HttpHandler> middlewares = const []}) → Future<void>
A PATCH request handler that matches a specific route.
post(String match, HttpHandler handler, {List<OidcOptions>? security, List<HttpHandler> middlewares = const []}) → Future<void>
A POST request handler that matches a specific route.
put(String match, HttpHandler handler, {List<OidcOptions>? security, List<HttpHandler> middlewares = const []}) → Future<void>
A PUT request handler that matches a specific route.
register() → Future<void>
Register the resource with the Nitric server. Handles shutting down the channel.
inherited
route(String match, {List<OidcOptions>? security, List<HttpHandler> middlewares = const []}) → Route
Create a route that matches on a specific path with optional middlewares and security.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited