ApiOptions class

Constructors

ApiOptions({List<OidcOptions> security = const [], String basePath = "", List<HttpHandler> middlewares = const []})

Properties

basePath ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
middlewares ↔ List<HttpHandler>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
security ↔ List<OidcOptions>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited