JobResource class

Inheritance

Constructors

JobResource(String name)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the resource.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allow(List<JobPermission> permissions) → Job
Set the function's required permissions to the batch.
asRequest() → ResourceDeclareRequest
override
handler(JobHandler handler, {JobResourceRequirements? opts, List<JobHandler> middlewares = const []}) → Future<void>
Create a handler function that will be executed when a job is submitted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
permissionsToActions(List<JobPermission> permissions) → List<Action>
Convert a list of permissions to gRPC actions.
override
register() → Future<void>
Register the resource with the Nitric server.
inherited
registerPolicy(List<JobPermission> permissions) → Future<void>
Register a policy with the Nitric server to secure the resource with least-privilege. Handles shutting down the channel.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited