OidcOptions class

Constructors

OidcOptions(String name, String issuer, List<String> audiences, List<String> scopes)

Properties

audiences ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuer ↔ String
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ List<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited