OidcSecurityDefinition class

Inheritance

Constructors

OidcSecurityDefinition(String apiName, OidcOptions options)

Properties

apiName ↔ String
getter/setter pair
audiences ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuer ↔ String
getter/setter pair
name → String
The name of the resource.
finalinherited
ruleName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asRequest() → ResourceDeclareRequest
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register() → Future<void>
Register the resource with the Nitric server. Handles shutting down the channel.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited