Resource class abstract

A representation of a resource that can be registered with the Nitric server.

Implementers

Constructors

Resource(String name)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the resource.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asRequest() → ResourceDeclareRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register() → Future<void>
Register the resource with the Nitric server. Handles shutting down the channel.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited