SecureResource<T extends Enum> class abstract

A resource that requires permissions to access it.

Inheritance
Implementers

Constructors

SecureResource(String name)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the resource.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asRequest() → ResourceDeclareRequest
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
permissionsToActions(List<T> permissions) → List<Action>
Convert a list of permissions to gRPC actions.
register() → Future<void>
Register the resource with the Nitric server.
override
registerPolicy(List<T> permissions) → Future<void>
Register a policy with the Nitric server to secure the resource with least-privilege. Handles shutting down the channel.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited